==> blender_downloader-0.0.3.tar.gz: blender_downloader-0.0.3/README.md <==
# blender-downloader

[![PyPI][pypi-version-badge-link]][pypi-link]
[![Python versions][pypi-pyversions-badge-link]][pypi-link]
[![License][license-image]][license-link]
[![Tests][tests-image]][tests-link]

Multiplatorm Python CLI utility that just downloads a specific portable
release of Blender by version/os/bits from official Blender repositories. The
minimum supported version is v2.64.

## Install

```bash
pip install blender-downloader
```

## Usage

> Execute `blender-downloader --help` to see all supported arguments.

### Download release by version number

```bash
blender-downloader 2.90
```

### Download current stable release

```bash
blender-downloader stable
```

### Download nightly release and extract/mount it

```bash
blender-downloader nightly --extract
```

### Download stable release, extract/mount and print `blender` executable location

```bash
blender-downloader stable --extract --print-blender-executable
```

[pypi-link]: https://pypi.org/project/blender-downloader
[pypi-version-badge-link]: https://img.shields.io/pypi/v/blender-downloader
[pypi-pyversions-badge-link]: https://img.shields.io/pypi/pyversions/blender-downloader
[license-image]: https://img.shields.io/pypi/l/blender-downloader?color=light-green
[license-link]: https://github.com/mondeja/blender-downloader/blob/master/LICENSE
[tests-image]: https://img.shields.io/github/workflow/status/mondeja/blender-downloader/CI
[tests-link]: https://github.com/mondeja/blender-downloader/actions?query=workflow%3ACI

==> blender_downloader-0.0.4.tar.gz: blender_downloader-0.0.4/README.md <==
# blender-downloader

[![PyPI][pypi-version-badge-link]][pypi-link]
[![Python versions][pypi-pyversions-badge-link]][pypi-link]
[![License][license-image]][license-link]
[![Tests][tests-image]][tests-link]

Multiplatorm Python CLI utility that downloads a specific portable release of
Blender by version/os/bits from official Blender repositories. The minimum
supported version is v2.64.

## Install

```bash
pip install blender-downloader
```

## Usage

> Execute `blender-downloader --help` to see all supported arguments.

### Download release by version number

```bash
blender-downloader 2.90
```

### Download current stable release

```bash
blender-downloader stable
```

### Download nightly release and extract/mount it

```bash
blender-downloader nightly --extract
```

### Download stable release, extract/mount and print `blender` executable location

```bash
blender-downloader stable --extract --print-blender-executable
```

[pypi-link]: https://pypi.org/project/blender-downloader
[pypi-version-badge-link]: https://img.shields.io/pypi/v/blender-downloader
[pypi-pyversions-badge-link]: https://img.shields.io/pypi/pyversions/blender-downloader
[license-image]: https://img.shields.io/pypi/l/blender-downloader?color=light-green
[license-link]: https://github.com/mondeja/blender-downloader/blob/master/LICENSE
[tests-image]: https://img.shields.io/github/workflow/status/mondeja/blender-downloader/CI
[tests-link]: https://github.com/mondeja/blender-downloader/actions?query=workflow%3ACI
